Struct JavaScriptExtensionPackage
pub struct JavaScriptExtensionPackage { /* private fields */ }Expand description
Complete immutable ECMAScript module graph supplied by trusted Rust code.
Module names are logical slash-separated paths. Static imports may only be relative and must resolve to another module in this graph. The Utility process never reads extension files itself.
Implementations
impl JavaScriptExtensionPackage
impl JavaScriptExtensionPackage
pub fn new(
entry: impl Into<String>,
) -> Result<JavaScriptExtensionPackage, JavaScriptExtensionError>
pub fn new( entry: impl Into<String>, ) -> Result<JavaScriptExtensionPackage, JavaScriptExtensionError>
Creates an empty graph whose eventual entry module has entry as its
logical name.
pub fn add_module(
self,
name: impl Into<String>,
source: impl Into<String>,
) -> Result<JavaScriptExtensionPackage, JavaScriptExtensionError>
pub fn add_module( self, name: impl Into<String>, source: impl Into<String>, ) -> Result<JavaScriptExtensionPackage, JavaScriptExtensionError>
Adds one source-text module. Names must be unique, relative logical
paths ending in .mjs; sources and the whole graph are bounded.
pub fn module_count(&self) -> usize
pub fn module_count(&self) -> usize
Returns the number of immutable modules in the graph.